
import objectdraw.*;
import java.awt.*;

public class CarpetEvents extends FrameWindowController {

    private static final int WINDOW_SIZE = 600;
    
    // the upper left corner of the carpet
    private static final Location UPPER_LEFT = new Location(50, 50);
    
    // the length of a side of the carpet
    private static final int SIDE_LENGTH = 400;

    // the carpet itself
    private Carpet carpet;

    // used to keep track of the last location of the carpet 
    // when the carpet is being dragged around
    private Location lastPoint;

    private boolean grabbed = false;

    // create the Carpet object
    public void begin() { 
        resize(WINDOW_SIZE, WINDOW_SIZE);
        carpet = new Carpet(UPPER_LEFT, SIDE_LENGTH, canvas);
    } 

    // save the location of the mouse press
    public void onMousePress(Location point) {
        if (carpet.contains(point)) {
            grabbed = true;
            lastPoint = point;
        }
    }

    public void onMouseRelease(Location point) {
        grabbed = false;
    }

    // Move the carpet around by calling the Carpet
    // move method and moving the carpet by the x and y
    // offsets that are the difference between the current
    // location of the mouse and the previous location ("lastPoint").
    public void onMouseDrag(Location point) {
        if (grabbed) {
            carpet.move(point.getX() - lastPoint.getX(), 
                point.getY() - lastPoint.getY());
            lastPoint = point;
        }
    }

}